@@ -8,18 +8,20 @@ from .models.binance import (
     BinanceSpotDataStore,
     BinanceUSDSMDataStore,
 )
-from .models.bitbank import bitbankDataStore
+from .models.bitbank import bitbankDataStore, bitbankPrivateDataStore
 from .models.bitflyer import bitFlyerDataStore
 from .models.bitget import BitgetDataStore
+from .models.bitget_v2 import BitgetV2DataStore
 from .models.bitmex import BitMEXDataStore
 from .models.bybit import BybitDataStore
 from .models.coincheck import CoincheckDataStore
 from .models.gmocoin import GMOCoinDataStore
+from .models.hyperliquid import HyperliquidDataStore
 from .models.kucoin import KuCoinDataStore
 from .models.okx import OKXDataStore
 from .models.phemex import PhemexDataStore
 from .store import DataStore, DataStoreCollection, StoreChange, StoreStream
-from .ws import WebSocketApp, WebSocketQueue
+from .ws import ClientWebSocketResponse, WebSocketApp, WebSocketQueue
 
 __all__: tuple[str, ...] = (
     # version
@@ -29,6 +31,7 @@ __all__: tuple[str, ...] = (
     "FetchResult",
     "NotJSONContent",
     # ws
+    "ClientWebSocketResponse",
     "WebSocketApp",
     "WebSocketQueue",
     # store
@@ -41,15 +44,18 @@ __all__: tuple[str, ...] = (
     "BinanceSpotDataStore",
     "BinanceUSDSMDataStore",
     "BitMEXDataStore",
+    "BitgetV2DataStore",
     "BitgetDataStore",
     "BybitDataStore",
     "CoincheckDataStore",
     "GMOCoinDataStore",
+    "HyperliquidDataStore",
     "KuCoinDataStore",
     "OKXDataStore",
     "PhemexDataStore",
     "bitFlyerDataStore",
     "bitbankDataStore",
+    "bitbankPrivateDataStore",
     # auth
     "Auth",
 )
