@@ -6,7 +6,7 @@ import hashlib
 import hmac
 import time
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 from urllib.parse import urlencode
 
 from aiohttp.formdata import FormData
@@ -15,7 +15,11 @@ from aiohttp.payload import JsonPayload
 from multidict import CIMultiDict, MultiDict
 from yarl import URL
 
+from pybotters.helpers import hyperliquid
+
 if TYPE_CHECKING:
+    from collections.abc import Callable, MutableMapping
+
     import aiohttp
 
 
@@ -33,7 +37,8 @@ class Auth:
         timestamp = str(int(time.time() * 1000))
         query_string = url.raw_query_string
         body = JsonPayload(data) if data else FormData(data)()
-        text = f"{timestamp}{key}{query_string}".encode() + body._value
+        recv_window = headers.get("X-BAPI-RECV-WINDOW", "")
+        text = f"{timestamp}{key}{recv_window}{query_string}".encode() + body._value
         signature = hmac.new(secret, text, hashlib.sha256).hexdigest()
         kwargs.update({"data": body})
         headers.update(
@@ -254,7 +259,7 @@ class Auth:
         secret: bytes = session.__dict__["_apis"][api_name][1]
         passphrase: str = session.__dict__["_apis"][api_name][2]
 
-        timestamp = f'{datetime.datetime.utcnow().isoformat(timespec="milliseconds")}Z'
+        timestamp = f"{datetime.datetime.utcnow().isoformat(timespec='milliseconds')}Z"
         body = JsonPayload(data) if data else FormData(data)()
         text = f"{timestamp}{method}{url.raw_path_qs}".encode() + body._value
         sign = base64.b64encode(
@@ -419,7 +424,7 @@ class Auth:
         secret: bytes = session.__dict__["_apis"][Hosts.items[url.host].name][1]
         passphrase: str = session.__dict__["_apis"][Hosts.items[url.host].name][2]
 
-        timestamp = f'{datetime.datetime.utcnow().isoformat(timespec="milliseconds")}Z'
+        timestamp = f"{datetime.datetime.utcnow().isoformat(timespec='milliseconds')}Z"
         body = JsonPayload(data) if data else FormData(data)()
         text = f"{timestamp}{method}{url.raw_path_qs}".encode() + body._value
         sign = base64.b64encode(
@@ -478,6 +483,57 @@ class Auth:
 
         return (method, url)
 
+    @staticmethod
+    def _hyperliquid(
+        data: MutableMapping[str, Any], url: URL, private_key: str, /
+    ) -> None:
+        action: dict[str, Any] = data.get("action", {})
+        nonce: int = data.setdefault("nonce", hyperliquid.get_timestamp_ms())
+        vault_address: str | None = data.get("vaultAddress")
+        expires_after: int | None = data.get("expiresAfter")
+
+        if "signature" not in data:
+            eip712_typed_data: tuple[
+                hyperliquid.EIP712Domain,
+                hyperliquid.MessageTypes,
+                hyperliquid.MessageData,
+            ]
+            # sign_l1_action
+            if "hyperliquidChain" not in action:
+                is_mainnet = isinstance(url.host, str) and "testnet" not in url.host
+                eip712_typed_data = hyperliquid.construct_l1_action(
+                    action,
+                    nonce,
+                    is_mainnet,
+                    vault_address=vault_address,
+                    expires_after=expires_after,
+                )
+            # sign_user_signed_action
+            else:
+                eip712_typed_data = hyperliquid.construct_user_signed_action(action)
+                data["action"] = eip712_typed_data[2]  # MessageData
+
+            signature = hyperliquid.sign_typed_data(private_key, *eip712_typed_data)
+            data["signature"] = signature
+
+    @staticmethod
+    def hyperliquid(args: tuple[str, URL], kwargs: dict[str, Any]) -> tuple[str, URL]:
+        url: URL = args[1]
+        data: dict[str, Any] = kwargs["data"] or {}
+
+        session: aiohttp.ClientSession = kwargs["session"]
+        private_key: str = session.__dict__["_apis"][Hosts.items[url.host].name][0]
+
+        if url.path.startswith(("/info", "/ws")):
+            return args
+
+        Auth._hyperliquid(data, url, private_key)
+
+        if data:
+            kwargs.update({"data": JsonPayload(data)})
+
+        return args
+
 
 @dataclass
 class Item:
@@ -532,6 +588,8 @@ class Hosts:
         "api-futures.kucoin.com": Item("kucoin", Auth.kucoin),
         "www.okcoin.jp": Item("okj", Auth.okj),
         "api-cloud.bittrade.co.jp": Item("bittrade", Auth.bittrade),
+        "api.hyperliquid.xyz": Item("hyperliquid", Auth.hyperliquid),
+        "api.hyperliquid-testnet.xyz": Item("hyperliquid_testnet", Auth.hyperliquid),
     }
 
 
