@@ -16,7 +16,7 @@ logger = logging.getLogger(__name__)
 
 
 class BitgetDataStore(DataStoreCollection):
-    """Bitget の DataStoreCollection クラス"""
+    """DataStoreCollection for Bitget V1 API"""
 
     def _init(self) -> None:
         self._create("trade", datastore_class=Trade)
@@ -47,7 +47,7 @@ class BitgetDataStore(DataStoreCollection):
                         f"Data: {data}"
                     )
 
-    def _onmessage(self, msg: Item, ws: ClientWebSocketResponse) -> None:
+    def _onmessage(self, msg: Item, ws: ClientWebSocketResponse | None = None) -> None:
         if "arg" in msg and "data" in msg:
             channel = msg["arg"].get("channel")
             if channel == "trade":
