@@ -4,9 +4,11 @@ import asyncio
 import copy
 import uuid
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Hashable, Iterator, Literal, TypeVar, overload
+from typing import TYPE_CHECKING, Any, Literal, TypeVar, overload
 
 if TYPE_CHECKING:
+    from collections.abc import Hashable, Iterator
+
     from .typedefs import Item
     from .ws import ClientWebSocketResponse
 
@@ -395,10 +397,10 @@ class DataStoreCollection:
     def _get(self, name: str, type_: type[DataStore] | None = None) -> DataStore | None:
         return self._stores.get(name)
 
-    def _onmessage(self, msg: Any, ws: ClientWebSocketResponse) -> None:
+    def _onmessage(self, msg: Any, ws: ClientWebSocketResponse | None = None) -> None:
         print(msg)
 
-    def onmessage(self, msg: Any, ws: ClientWebSocketResponse) -> None:
+    def onmessage(self, msg: Any, ws: ClientWebSocketResponse | None = None) -> None:
         """WebSocket message handler.
 
         :meth:`.Client.ws_connect` に渡すコールバックです。
