@@ -7,8 +7,10 @@ if TYPE_CHECKING:
     from collections.abc import Awaitable, Callable, Coroutine
     from contextlib import AbstractAsyncContextManager
 
+    import aiohttp
     from _typeshed import StrOrBytesPath as StrOrBytesPath
-    from aiohttp.client_ws import ClientResponse, ClientWebSocketResponse
+
+    from .ws import ClientWebSocketResponse
 
     if sys.version_info >= (3, 10):
         from typing import TypeAlias
@@ -16,12 +18,14 @@ if TYPE_CHECKING:
         from typing_extensions import TypeAlias
 
     class RequestContextManager(
-        Awaitable[ClientResponse], AbstractAsyncContextManager[ClientResponse], Protocol
+        Awaitable[aiohttp.ClientResponse],
+        AbstractAsyncContextManager[aiohttp.ClientResponse],
+        Protocol,
     ): ...
 
-    APICredentialsDict: TypeAlias = "dict[str, list[str]]"
-    EncodedAPICredential: TypeAlias = "tuple[str, bytes, str]"
-    EncodedAPICredentialsDict: TypeAlias = "dict[str, EncodedAPICredential]"
+    APICredentialsDict: TypeAlias = dict[str, list[str]]
+    EncodedAPICredential: TypeAlias = tuple[str, bytes, str]
+    EncodedAPICredentialsDict: TypeAlias = dict[str, EncodedAPICredential]
 
     WsStrHandler = Callable[[str, ClientWebSocketResponse], None]
     WsBytesHandler = Callable[[bytes, ClientWebSocketResponse], None]
@@ -32,4 +36,4 @@ if TYPE_CHECKING:
         [ClientWebSocketResponse, Awaitable[None]], Awaitable[None]
     ]
 
-    Item: TypeAlias = "dict[str, Any]"
+    Item: TypeAlias = dict[str, Any]
