@@ -6,6 +6,7 @@ import datetime
 import hashlib
 import hmac
 import inspect
+import json
 import logging
 import random
 import struct
@@ -14,15 +15,20 @@ import uuid
 import zlib
 from dataclasses import dataclass
 from secrets import token_hex
-from typing import TYPE_CHECKING, Any, AsyncIterator, Awaitable, Generator, cast
+from typing import TYPE_CHECKING, Any, cast
 from urllib.parse import urlencode
 
 import aiohttp
-from aiohttp.http_websocket import json
 
 from .auth import Auth as _Auth
 
 if TYPE_CHECKING:
+    from collections.abc import (
+        AsyncIterator,
+        Awaitable,
+        Generator,
+    )
+
     from .typedefs import (
         WsBytesHandler,
         WsHeartBeatHandler,
@@ -73,7 +79,7 @@ class WebSocketApp:
         self._url = url
 
         self._loop = session._loop
-        self._current_ws: aiohttp.ClientWebSocketResponse | None = None
+        self._current_ws: ClientWebSocketResponse | None = None
         self._event = asyncio.Event()
 
         self._autoping = kwargs.pop("autoping", True)
@@ -136,7 +142,7 @@ class WebSocketApp:
         self._url = url
 
     @property
-    def current_ws(self) -> aiohttp.ClientWebSocketResponse | None:
+    def current_ws(self) -> ClientWebSocketResponse | None:
         """Current WebSocket connection.
 
         現在の WebSocket コネクションです。
@@ -201,10 +207,11 @@ class WebSocketApp:
         **kwargs: Any,
     ) -> None:
         async with self._session.ws_connect(self._url, autoping=False, **kwargs) as ws:
+            ws = cast("ClientWebSocketResponse", ws)
             self._current_ws = ws
             self._event.set()
 
-            await cast(ClientWebSocketResponse, ws)._wait_authtask()
+            await ws._wait_authtask()
 
             await self._ws_send(ws, send_str, send_bytes, send_json)
 
@@ -212,7 +219,7 @@ class WebSocketApp:
 
     async def _ws_send(
         self,
-        ws: aiohttp.ClientWebSocketResponse,
+        ws: ClientWebSocketResponse,
         send_str: list[str],
         send_bytes: list[bytes],
         send_json: list[dict],
@@ -225,7 +232,7 @@ class WebSocketApp:
 
     async def _ws_receive(
         self,
-        ws: aiohttp.ClientWebSocketResponse,
+        ws: ClientWebSocketResponse,
         hdlr_str: list[WsStrHandler],
         hdlr_bytes: list[WsBytesHandler],
         hdlr_json: list[WsJsonHandler],
@@ -238,7 +245,7 @@ class WebSocketApp:
     def _onmessage(
         self,
         msg: aiohttp.WSMessage,
-        ws: aiohttp.ClientWebSocketResponse,
+        ws: ClientWebSocketResponse,
         hdlr_str: list[WsStrHandler],
         hdlr_bytes: list[WsBytesHandler],
         hdlr_json: list[WsJsonHandler],
@@ -321,7 +328,7 @@ class WebSocketApp:
 class WebSocketQueue(asyncio.Queue):
     """WebSocket queue (from asyncio.Queue)."""
 
-    def onmessage(self, msg: Any, ws: aiohttp.ClientWebSocketResponse):
+    def onmessage(self, msg: Any, ws: ClientWebSocketResponse):
         """WebSocket message hander callback."""
         self.put_nowait(msg)
 
@@ -333,37 +340,37 @@ class WebSocketQueue(asyncio.Queue):
 
 class Heartbeat:
     @staticmethod
-    async def bybit(ws: aiohttp.ClientWebSocketResponse):
+    async def bybit(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str('{"op":"ping"}')
             await asyncio.sleep(20.0)
 
     @staticmethod
-    async def bitbank(ws: aiohttp.ClientWebSocketResponse):
+    async def bitbank(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str("2")
             await asyncio.sleep(15.0)
 
     @staticmethod
-    async def binance(ws: aiohttp.ClientWebSocketResponse):
+    async def binance(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.pong()
             await asyncio.sleep(60.0)
 
     @staticmethod
-    async def phemex(ws: aiohttp.ClientWebSocketResponse):
+    async def phemex(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str('{"method":"server.ping","params":[],"id":123}')
             await asyncio.sleep(10.0)
 
     @staticmethod
-    async def okx(ws: aiohttp.ClientWebSocketResponse):
+    async def okx(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str("ping")
             await asyncio.sleep(15.0)
 
     @staticmethod
-    async def bitget(ws: aiohttp.ClientWebSocketResponse):
+    async def bitget(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str("ping")
             # Refer to official SDK
@@ -371,25 +378,25 @@ class Heartbeat:
             await asyncio.sleep(25.0)
 
     @staticmethod
-    async def mexc(ws: aiohttp.ClientWebSocketResponse):
+    async def mexc(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str('{"method":"ping"}')
             await asyncio.sleep(10.0)
 
     @staticmethod
-    async def kucoin(ws: aiohttp.ClientWebSocketResponse):
+    async def kucoin(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str(f'{{"id": "{uuid.uuid4()}", "type": "ping"}}')
             await asyncio.sleep(15)
 
     @staticmethod
-    async def okj(ws: aiohttp.ClientWebSocketResponse):
+    async def okj(ws: ClientWebSocketResponse):
         while not ws.closed:
             await ws.send_str("ping")
             await asyncio.sleep(15.0)
 
     @staticmethod
-    async def bittrade(ws: aiohttp.ClientWebSocketResponse):
+    async def bittrade(ws: ClientWebSocketResponse):
         # Retail
         if ws._response.url.path == "/retail/ws":
             while not ws.closed:
@@ -409,10 +416,16 @@ class Heartbeat:
                 await ws.send_json({"action": "pong", "data": {"ts": ts}})
                 await asyncio.sleep(20.0)
 
+    @staticmethod
+    async def hyperliquid(ws: ClientWebSocketResponse):
+        while not ws.closed:
+            await ws.send_str('{"method":"ping"}')
+            await asyncio.sleep(30.0)
+
 
 class Auth:
     @staticmethod
-    async def bybit(ws: aiohttp.ClientWebSocketResponse):
+    async def bybit(ws: ClientWebSocketResponse):
         if "public" in ws._response.url.parts:
             return
 
@@ -438,7 +451,7 @@ class Auth:
                 break
 
     @staticmethod
-    async def bitflyer(ws: aiohttp.ClientWebSocketResponse):
+    async def bitflyer(ws: ClientWebSocketResponse):
         key: str = ws._response._session.__dict__["_apis"][
             AuthHosts.items[ws._response.url.host].name
         ][0]
@@ -471,7 +484,7 @@ class Auth:
                 break
 
     @staticmethod
-    async def phemex(ws: aiohttp.ClientWebSocketResponse):
+    async def phemex(ws: ClientWebSocketResponse):
         key: str = ws._response._session.__dict__["_apis"][
             AuthHosts.items[ws._response.url.host].name
         ][0]
@@ -497,7 +510,7 @@ class Auth:
                 break
 
     @staticmethod
-    async def okx(ws: aiohttp.ClientWebSocketResponse):
+    async def okx(ws: ClientWebSocketResponse):
         key: str = ws._response._session.__dict__["_apis"][
             AuthHosts.items[ws._response.url.host].name
         ][0]
@@ -539,7 +552,10 @@ class Auth:
                     break
 
     @staticmethod
-    async def bitget(ws: aiohttp.ClientWebSocketResponse):
+    async def bitget(ws: ClientWebSocketResponse):
+        if "public" in ws._response.url.parts:
+            return
+
         key: str = ws._response._session.__dict__["_apis"][
             AuthHosts.items[ws._response.url.host].name
         ][0]
@@ -582,7 +598,7 @@ class Auth:
                     break
 
     @staticmethod
-    async def mexc(ws: aiohttp.ClientWebSocketResponse):
+    async def mexc(ws: ClientWebSocketResponse):
         key: str = ws._response._session.__dict__["_apis"][
             AuthHosts.items[ws._response.url.host].name
         ][0]
@@ -606,7 +622,7 @@ class Auth:
         await ws.send_json(msg)
 
     @staticmethod
-    async def okj(ws: aiohttp.ClientWebSocketResponse):
+    async def okj(ws: ClientWebSocketResponse):
         key: str = ws._response._session.__dict__["_apis"][
             AuthHosts.items[ws._response.url.host].name
         ][0]
@@ -643,7 +659,7 @@ class Auth:
                     break
 
     @staticmethod
-    async def bittrade(ws: aiohttp.ClientWebSocketResponse):
+    async def bittrade(ws: ClientWebSocketResponse):
         method = "GET"
         host = ws._response.url.host
         path = ws._response.url.path
@@ -733,6 +749,8 @@ class HeartbeatHosts:
         "ws-api-futures.kucoin.com": Heartbeat.kucoin,
         "connect.okcoin.jp": Heartbeat.okj,
         "api-cloud.bittrade.co.jp": Heartbeat.bittrade,
+        "api.hyperliquid.xyz": Heartbeat.hyperliquid,
+        "api.hyperliquid-testnet.xyz": Heartbeat.hyperliquid,
     }
 
 
@@ -760,6 +778,10 @@ class AuthHosts:
 
 
 class ClientWebSocketResponse(aiohttp.ClientWebSocketResponse):
+    """Class for handling client-side websockets.
+
+    This class is a subclass of :class:`aiohttp.ClientWebSocketResponse`."""
+
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         if self._response.url.host in HeartbeatHosts.items:
@@ -782,6 +804,7 @@ class ClientWebSocketResponse(aiohttp.ClientWebSocketResponse):
             await self.__dict__["_authtask"]
 
     async def send_str(self, *args, **kwargs) -> None:
+        """Send *data* to peer as :attr:`aiohttp.WSMsgType.TEXT` message."""
         if self._response.url.host not in RequestLimitHosts.items:
             await super().send_str(*args, **kwargs)
         else:
@@ -789,6 +812,7 @@ class ClientWebSocketResponse(aiohttp.ClientWebSocketResponse):
             await RequestLimitHosts.items[self._response.url.host](self, super_send_str)
 
     async def send_json(self, *args, **kwargs) -> None:
+        """Send *data* to peer as JSON string."""
         if (
             (kwargs.pop("auth", _Auth) is _Auth)
             and (self._response.url.host in MessageSignHosts.items)
@@ -806,9 +830,9 @@ class ClientWebSocketResponse(aiohttp.ClientWebSocketResponse):
 
 class RequestLimit:
     @staticmethod
-    async def gmocoin(ws: aiohttp.ClientWebSocketResponse, send_str: Awaitable[None]):
-        session = cast(aiohttp.ClientSession, ws._response._session)
-        async with cast(ClientWebSocketResponse, ws)._lock:
+    async def gmocoin(ws: ClientWebSocketResponse, send_str: Awaitable[None]):
+        session = cast("aiohttp.ClientSession", ws._response._session)
+        async with ws._lock:
             await send_str
             r = await session.get("https://api.coin.z.com/public/v1/status", auth=_Auth)
             data = await r.json()
@@ -825,11 +849,9 @@ class RequestLimit:
                     break
 
     @staticmethod
-    async def binance(
-        ws: aiohttp.ClientWebSocketResponse, send_str: Awaitable[None]
-    ) -> None:
-        session = cast(aiohttp.ClientSession, ws._response._session)
-        async with cast(ClientWebSocketResponse, ws)._lock:
+    async def binance(ws: ClientWebSocketResponse, send_str: Awaitable[None]) -> None:
+        session = cast("aiohttp.ClientSession", ws._response._session)
+        async with ws._lock:
             await send_str
             r = await session.get("https://api.binance.com/api/v3/time", auth=None)
             data = await r.json()
@@ -853,7 +875,7 @@ class RequestLimitHosts:
 
 class MessageSign:
     @staticmethod
-    def binance(ws: aiohttp.ClientWebSocketResponse, data: dict[str, Any]):
+    def binance(ws: ClientWebSocketResponse, data: dict[str, Any]):
         key: str = ws._response._session.__dict__["_apis"][
             MessageSignHosts.items[ws._response.url.host].name
         ][0]
@@ -874,13 +896,35 @@ class MessageSign:
         params["signature"] = signature
 
     @staticmethod
-    def bybit(ws: aiohttp.ClientWebSocketResponse, data: dict[str, Any]):
+    def bybit(ws: ClientWebSocketResponse, data: dict[str, Any]):
         if "trade" not in ws._response.url.parts:
             return
 
         if "header" not in data:
             data["header"] = {"X-BAPI-TIMESTAMP": str(int(time.time() * 1000))}
 
+    @staticmethod
+    def hyperliquid(ws: ClientWebSocketResponse, data: object) -> None:
+        url = ws._response.url
+        private_key: str = ws._response._session.__dict__["_apis"][
+            MessageSignHosts.items[url.host].name
+        ][0]
+
+        if not isinstance(data, dict):
+            return
+
+        method = data.get("method")
+        request = data.get("request")
+        if not (method == "post" and isinstance(request, dict)):
+            return
+
+        type_ = request.get("type")
+        payload = request.get("payload")
+        if not (type_ == "action" and isinstance(payload, dict)):
+            return
+
+        _Auth._hyperliquid(payload, url, private_key)
+
 
 class MessageSignHosts:
     # NOTE: yarl.URL.host is also allowed to be None. So, for brevity, relax the type check on the `items` key.
@@ -890,4 +934,8 @@ class MessageSignHosts:
         "stream.bybit.com": Item("bybit", MessageSign.bybit),
         "stream-demo.bybit.com": Item("bybit_demo", MessageSign.bybit),
         "stream-testnet.bybit.com": Item("bybit_testnet", MessageSign.bybit),
+        "api.hyperliquid.xyz": Item("hyperliquid", MessageSign.hyperliquid),
+        "api.hyperliquid-testnet.xyz": Item(
+            "hyperliquid_testnet", MessageSign.hyperliquid
+        ),
     }
