@@ -1,15 +1,17 @@
 from __future__ import annotations
 
 import asyncio
+import copy
 import functools
 import json
 import logging
 import zlib
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import TYPE_CHECKING
 from unittest.mock import ANY, AsyncMock, MagicMock, PropertyMock, call
 
 import aiohttp
+import freezegun
 import pytest
 import pytest_asyncio
 from aiohttp import web
@@ -432,7 +434,7 @@ async def test_websocketapp_ensure_open_hdlr(
             ws = await client.ws_connect(
                 f"ws://localhost:{test_ping_pong_server.port}/ws",
                 hdlr_json=wsq.onmessage,
-                heartbeat=None,
+                heartbeat=10.0,
                 autoping=True,
             )
             await ws.heartbeat(0.1)
@@ -448,7 +450,8 @@ async def test_websocketapp_ensure_open_hdlr(
     assert received_messages == [{"data": "spam"}]
     assert wstask.cancelled()
 
-    assert caplog.records == []  # No handler errors
+    records = [x for x in caplog.records if x.name == "pybotters.ws"]
+    assert records == []  # No handler errors
 
 
 def test_heartbeathosts():
@@ -641,7 +644,9 @@ async def test_wsresponse_send_json():
     )
     await asyncio.wait_for(wsresp.send_json({"foo": "bar"}), timeout=5.0)
 
-    assert m_writer.send.call_args == call('{"foo": "bar"}', binary=ANY, compress=ANY)
+    assert m_writer.send_frame.call_args == call(
+        b'{"foo": "bar"}', aiohttp.WSMsgType.TEXT, compress=None
+    )
 
 
 @pytest.mark.asyncio
@@ -794,6 +799,7 @@ async def test_websocketqueue():
         (pybotters.ws.Heartbeat.mexc,),
         (pybotters.ws.Heartbeat.kucoin,),
         (pybotters.ws.Heartbeat.okj,),
+        (pybotters.ws.Heartbeat.hyperliquid,),
     ],
 )
 async def test_heartbeat_text(mocker: pytest_mock.MockerFixture, test_input):
@@ -1344,6 +1350,7 @@ async def test_auth_okx_ws(
         # signed
         (
             {
+                "url": URL("wss://ws.bitget.com/v2/ws/private"),
                 "messages": [
                     aiohttp.WSMessage(
                         aiohttp.WSMsgType.TEXT,
@@ -1358,12 +1365,26 @@ async def test_auth_okx_ws(
                 ],
             },
             {
+                "call_args": call(
+                    {
+                        "op": "login",
+                        "args": [
+                            {
+                                "api_key": "jbcfbye8AJzXxXwMKluXM12t",
+                                "passphrase": "MyPassphrase123",
+                                "timestamp": "2085848896",
+                                "sign": "RmRhCixsMce8H7j2uyvR6sk11tCRbYenohbd87nchH8=",
+                            }
+                        ],
+                    }
+                ),
                 "records": [],
             },
         ),
         # invalid signature
         (
             {
+                "url": URL("wss://ws.bitget.com/v2/ws/private"),
                 "messages": [
                     aiohttp.WSMessage(
                         aiohttp.WSMsgType.TEXT,
@@ -1373,9 +1394,30 @@ async def test_auth_okx_ws(
                 ],
             },
             {
+                "call_args": call(
+                    {
+                        "op": "login",
+                        "args": [
+                            {
+                                "api_key": "jbcfbye8AJzXxXwMKluXM12t",
+                                "passphrase": "MyPassphrase123",
+                                "timestamp": "2085848896",
+                                "sign": "RmRhCixsMce8H7j2uyvR6sk11tCRbYenohbd87nchH8=",
+                            }
+                        ],
+                    }
+                ),
                 "records": [("pybotters.ws", logging.WARNING, ANY)],
             },
         ),
+        # not signed
+        (
+            {
+                "url": URL("wss://ws.bitget.com/v2/ws/public"),
+                "messages": [],
+            },
+            {"call_args": None, "records": []},
+        ),
     ],
 )
 async def test_auth_bitget_ws(
@@ -1387,7 +1429,7 @@ async def test_auth_bitget_ws(
     mocker.patch("time.time", return_value=2085848896.0)
 
     m_wsresp = AsyncMock()
-    m_wsresp._response.url = URL("wss://ws.bitget.com/mix/v1/stream")
+    m_wsresp._response.url = test_input["url"]
     m_wsresp._response._session.__dict__["_apis"] = {
         "bitget": (
             "jbcfbye8AJzXxXwMKluXM12t",
@@ -1399,19 +1441,7 @@ async def test_auth_bitget_ws(
 
     await asyncio.wait_for(pybotters.ws.Auth.bitget(m_wsresp), timeout=5.0)
 
-    assert m_wsresp.send_json.call_args == call(
-        {
-            "op": "login",
-            "args": [
-                {
-                    "api_key": "jbcfbye8AJzXxXwMKluXM12t",
-                    "passphrase": "MyPassphrase123",
-                    "timestamp": "2085848896",
-                    "sign": "RmRhCixsMce8H7j2uyvR6sk11tCRbYenohbd87nchH8=",
-                }
-            ],
-        }
-    )
+    assert m_wsresp.send_json.call_args == expected["call_args"]
     assert [x for x in caplog.record_tuples if x[0] == "pybotters.ws"] == expected[
         "records"
     ]
@@ -1896,3 +1926,128 @@ def test_msgsign_bybit(mocker: pytest_mock.MockerFixture, test_input, expected):
     pybotters.ws.MessageSign.bybit(m_wsresp, test_input["data"])
 
     assert test_input["data"] == expected["data"]
+
+
+@pytest.mark.parametrize(
+    ("test_input", "expected"),
+    [
+        # signed - testnet
+        (
+            # test_input
+            URL("wss://api.hyperliquid-testnet.xyz/ws"),
+            # expected
+            {
+                "nonce": 0,
+                "signature": {
+                    "r": "0x82b2ba28e76b3d761093aaded1b1cdad4960b3af30212b343fb2e6cdfa4e3d54",
+                    "s": "0x6b53878fc99d26047f4d7e8c90eb98955a109f44209163f52d8dc4278cbbd9f5",
+                    "v": 27,
+                },
+            },
+        ),
+        # signed - mainnet
+        (
+            # test_input
+            URL("wss://api.hyperliquid.xyz/ws"),
+            # expected
+            {
+                "nonce": 0,
+                "signature": {
+                    "r": "0xd65369825a9df5d80099e513cce430311d7d26ddf477f5b3a33d2806b100d78e",
+                    "s": "0x2b54116ff64054968aa237c20ca9ff68000f977c93289157748a3162b6ea940e",
+                    "v": 28,
+                },
+            },
+        ),
+    ],
+)
+def test_msgsign_hyperliquid(test_input, expected):
+    m_wsresp = AsyncMock()
+    m_wsresp._response._session.__dict__["_apis"] = {
+        "hyperliquid": (
+            "0x0123456789012345678901234567890123456789012345678901234567890123",
+        ),
+        "hyperliquid_testnet": (
+            "0x0123456789012345678901234567890123456789012345678901234567890123",
+        ),
+    }
+    m_wsresp._response.url = test_input
+    mutable_input = {
+        "method": "post",
+        "id": 256,
+        "request": {
+            "type": "action",
+            "payload": {
+                "action": {
+                    "type": "order",
+                    "orders": [
+                        {
+                            "a": 1,
+                            "b": True,
+                            "p": "100",
+                            "s": "100",
+                            "r": False,
+                            "t": {"limit": {"tif": "Gtc"}},
+                        }
+                    ],
+                    "grouping": "na",
+                }
+            },
+        },
+    }
+    full_expected = copy.deepcopy(mutable_input)
+    full_expected["request"]["payload"].update(expected)
+
+    with freezegun.freeze_time(datetime.fromtimestamp(0, tz=timezone.utc)):
+        pybotters.ws.MessageSignHosts.items[test_input.host].func(
+            m_wsresp, mutable_input
+        )
+
+    assert mutable_input == full_expected
+
+
+@pytest.mark.parametrize(
+    "test_input",
+    [
+        # not dict
+        42,
+        # method != "post"
+        {"method": "ping"},
+        # request not in dict
+        {"method": "post"},
+        # request.type != "action"
+        {
+            "method": "post",
+            "id": 123,
+            "request": {
+                "type": "info",
+                "payload": {
+                    "type": "l2Book",
+                    "coin": "ETH",
+                    "nSigFigs": 5,
+                    "mantissa": None,
+                },
+            },
+        },
+        # payload not in request
+        {
+            "method": "post",
+            "id": 256,
+            "request": {"type": "action"},
+        },
+    ],
+)
+def test_msgsign_hyperliquid_ignore(test_input):
+    m_wsresp = AsyncMock()
+    m_wsresp._response._session.__dict__["_apis"] = {
+        "hyperliquid": (
+            "0x0123456789012345678901234567890123456789012345678901234567890123",
+        ),
+    }
+    url = URL("wss://api.hyperliquid.xyz/ws")
+    m_wsresp._response.url = url
+    expected = copy.deepcopy(test_input)
+
+    pybotters.ws.MessageSignHosts.items[url.host].func(m_wsresp, test_input)
+
+    assert test_input == expected
